@@ -6,7 +6,7 @@ sel.coeffile <- function(fstring = "coef") {
   temp <- data(package = "bio.infer")
   flist <- temp$results[,3]
 
-  incvec <- substring(flist, 1, 4) == fstring
+  incvec <- substring(flist, 1, 4) == substring(fstring,1,4)
 
   flist <- flist[incvec]
 
